pub struct StringId<I = u16>(/* private fields */);Expand description
Identifier for one string in a crate::StringTable.
I is the backing integer type (default u16) and must implement
crate::StringIndex. It limits how many strings a single table can hold,
and it is what you store in your own structs to later refer to a string.
Implementations
Sourceimpl<I: StringIndex> StringId<I>
impl<I: StringIndex> StringId<I>
Sourcepub fn into_usize(self) -> usize
pub fn into_usize(self) -> usize
Returns the value as usize.