pub trait StringIndex:
Sealed
+ Copy
+ Eq
+ Ord
+ Debug
+ Display
+ Send
+ Sync
+ 'static {
const TYPE_NAME: &'static str;
// Required methods
fn try_from_usize(value: usize) -> Option<Self>;
fn to_usize(self) -> usize;
}Expand description
Contract for integer types used by crate::StringId.
Self::try_from_usize is used at build and validation boundaries where
counts are computed as usize. Self::to_usize is used on lookup paths
for infallible indexing.
This trait is sealed and only implemented for unsigned integers that fit in
usize on the current target.
Required Associated Constants
Required Methods
Sourcefn try_from_usize(value: usize) -> Option<Self>
fn try_from_usize(value: usize) -> Option<Self>
Converts a string index into this type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.